@@ -3,6 +3,7 @@
 import argparse
 import os
 import pdb
+import sys
 
 import pkg_resources
 
@@ -10,14 +11,15 @@ import pkg_resources
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument('script')
-    args = parser.parse_args()
+    args, scriptargs = parser.parse_known_args()
 
     script_name = os.path.basename(args.script)
     ep = pkg_resources.iter_entry_points('console_scripts', script_name).next()
     f = ep.load()
 
+    sys.argv = [args.script]
+    sys.argv.extend(scriptargs)
     pdb.runcall(f)
 
 if __name__ == '__main__':
-    import sys
     sys.exit(main())
